@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::NIGELM;
 use strict;
 use warnings;
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 our $AUTHORITY = 'cpan:NIGELM'; # AUTHORITY
 
 use Moose 1.00;
@@ -19,6 +19,7 @@ use MooseX::Types::Moose qw{ ArrayRef Str };
 use namespace::autoclean -also => 'lower';
 
 # these are all the modules used, listed purely for the dep generator
+use Dist::Zilla 5.033;    # force recent version of dzil
 use Dist::Zilla::Plugin::Authority 1.005;
 use Dist::Zilla::Plugin::AutoPrereqs;
 use Dist::Zilla::Plugin::CheckChangeLog;
@@ -488,6 +489,14 @@ method configure () {
         [ ManifestSkip => {} ],
 
         # -- get prereqs
+        [   Prereqs => {    # these are needed but not pulled in by other modules
+                -phase             => 'build',
+                -type              => 'requires',
+                'Test::CPAN::Meta' => 0,
+                'Test::EOL'        => 0,
+                'Test::NoTabs'     => 0
+            }
+        ],
         (   $self->auto_prereqs
             ? [ AutoPrereqs => $self->skip_prereqs ? { skip => $self->skip_prereqs } : {} ]
             : ()
@@ -583,7 +592,7 @@ Dist::Zilla::PluginBundle::NIGELM - Build your distributions like I do
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
